@@ -1,5 +1,5 @@
 from typing import Callable, NewType, List, Optional, Protocol, TypeVar, Iterable, Iterator, Tuple
-from hashlib import sha256
+from remerkleable.settings import Root, merkle_hash, zero_hashes
 
 
 # Get the depth required for a given element count
@@ -52,17 +52,6 @@ def concat_gindices(steps: Iterable[Gindex]) -> Gindex:
     return Gindex(out)
 
 
-Root = NewType("Root", bytes)
-
-MerkleFn = Callable[[Root, Root], Root]
-
-ZERO_ROOT: Root = Root(b'\x00' * 32)
-
-
-def merkle_hash(left: Root, right: Root) -> Root:
-    return Root(sha256(left + right).digest())
-
-
 Link = Callable[["Node"], "Node"]
 SummaryLink = Callable[[], "Node"]
 
@@ -117,13 +106,6 @@ class Node(Protocol):
         raise
 
 
-# hashes of hashes of zeroes etc.
-zero_hashes: List[Root] = [ZERO_ROOT]
-
-for i in range(100):
-    zero_hashes.append(merkle_hash(zero_hashes[i], zero_hashes[i]))
-
-
 def zero_node(depth: int) -> "RootNode":
     return RootNode(zero_hashes[depth])
 
